#!/usr/bin/env python

"""
Legal Information:
All information contained herein is, and remains the property of 
Vena Engineering Corporation. This source code contains proprietary 
information of Vena Engineering Corporation. It is intended solely 
for the information and use of parties operating and maintaining 
the equipment provided by Vena Engineering. Such proprietary 
information may not be used, reproduced, or disclosed to any other 
parties for any other purpose without the expressed written 
permission of Vena Engineering Corporation. The intellectual and 
technical concepts contained herein are proprietary to Vena 
Engineering Corporation and may be covered by U.S. and Foreign 
Patents, patents in process, and are protected by trade secret 
or copyright law. Dissemination of this information or reproduction 
of this material is strictly forbidden unless prior written permission 
is obtained from Vena Engineering Corporation. 
"""

from PyQt4 import QtGui
import sys
import motor

class MyButton(QtGui.QPushButton):
    def __init__(self, label, callback = None, parent=None):
        super(MyButton, self).__init__(label, parent)
        self.clicked.connect(callback)

class PimotionDialog(QtGui.QDialog):

    def __init__(self, parent=None):
        super(PimotionDialog, self).__init__(parent)
        self.setWindowTitle("Pimotion Hard Drive")

        spindleGb = QtGui.QGroupBox('Spindle')
        self.spindleRpm = QtGui.QDoubleSpinBox()
        self.spindleRpm.setRange(0.0, 10000.0)
        l = QtGui.QVBoxLayout()
        l.addWidget(QtGui.QLabel('RPM:'))
        l.addWidget(self.spindleRpm)
        l.addWidget(MyButton("Go", self.onSpindleGo))
        l.addWidget(MyButton("Stop", self.onSpindleStop))
        l.addWidget(MyButton("Reset", self.onSpindleReset))
        l.addWidget(MyButton("Off", self.onSpindleOff))
        l.addStretch(1)
        spindleGb.setLayout(l)

        actuatorGb = QtGui.QGroupBox('Actuator')        
        self.actuatorPattern = QtGui.QComboBox()        
        self.actuatorPattern.addItems(['Full Sweep', 'Random', 'Butterfly'])
        l = QtGui.QVBoxLayout()
        l.addWidget(QtGui.QLabel('Pattern:'))
        l.addWidget(self.actuatorPattern)
        l.addWidget(MyButton("Go", self.onActuatorGo))
        l.addWidget(MyButton("Stop", self.onActuatorStop))
        l.addWidget(MyButton("Home", self.onActuatorHome))
        l.addWidget(MyButton("Off", self.onActuatorOff))
        l.addStretch(1)
        actuatorGb.setLayout(l)

        mainLayout = QtGui.QHBoxLayout()
        self.setLayout(mainLayout)
        
        mainLayout.addWidget(spindleGb)
        mainLayout.addWidget(actuatorGb)

        self.spindle = motor.Spindle()
        self.actuator = motor.Actuator()
        
    def onSpindleGo(self):
        val = self.spindleRpm.value()
        self.spindle.go_rpm(val)        

    def onSpindleStop(self):
        self.spindle.stop()

    def onSpindleReset(self):
        self.spindle.reset_motor()

    def onSpindleOff(self):
        self.spindle.off()

    def onActuatorGo(self):
        pattern = self.actuatorPattern.currentText()
        self.actuator.move_pattern(pattern)        

    def onActuatorStop(self):
        self.actuator.stop()

    def onActuatorHome(self):
        self.actuator.home()

    def onActuatorOff(self):
        self.actuator.off()

if __name__ == '__main__':

    app = QtGui.QApplication(sys.argv)
    dialog = PimotionDialog()
    sys.exit(dialog.exec_())    
